@@ -13,7 +13,7 @@ import fontawesome.icons as fontawesome
 from pkg_resources import resource_filename
 from si_prefix import si_format
 
-__version__ = '0.0.9'
+__version__ = '0.0.10'
 
 
 def with_fontawesome(f):
@@ -61,6 +61,10 @@ def bootstrap_fontawesome():
     p.grid.visible = False
     p.outline_line_color = None
     p.rect([0.5], [0.5], [1.0], [1.0], fill_color=None)
+    p.add_layout(
+        Label(
+            x=0, y=0.3, text_font="FontAwesome", text_color=None,
+            text="{} FontAwesome loaded".format(fontawesome['check'])))
     show(p)
 
 
@@ -120,7 +124,10 @@ class InfoGraphItems(dict):
 
     def __init__(self, *args, **kwargs):
         """Initialize the helper, and bootstrap fontawesome."""
-        bootstrap_fontawesome()
+        try:
+            bootstrap_fontawesome()
+        except ImportError:
+            pass
         super().__init__(*args, **kwargs)
 
     def append(self, label, value, icon, unit=''):
